Rdzobot: Rządowe Dzentrum Bezpieczeństwa na skalę naszych możliwości
Rdzobot is a framework for writing Matrix bots in Rust programming language. Included are several modules:
autojoin: Automatically join channels when invited, and owner can instruct the bot to!leaveany channel.log: Logs room events to files.parcels: Generates QR codes for parcel lockers (currently supported operators: InPost and Orlen Paczka) and tracks parcel deliveries.
There are also two example-quality modules, used mostly in Warsaw Hackerspace:
hswaw: Assorted tooling for HS.newag: Adds!rozprawacommand, which queries when will be the next hearing in the civil case filed by Newag agains the Hackers.
Build
apt-get install \
libssl-dev \
libsqlite3-dev \
libpython3-dev \
#
cargo build --releaseRun
RDZB_PASSWORD=... ./target/release/rdzb-login
PYTHONPATH=. ./target/release/rdzb
## Log configuration
`/etc/systemd/system/rdzobot.service.d/log.conf`:
```ini
[Service]
Environment=RUST_LOG=rdzobot=debug,rdzb=debug,matrix_sdk=warnhttps://docs.rs/tracing-subscriber/latest/tracing_subscriber/filter/struct.EnvFilter.html#directives
Re-exports
pub use crate::bot::Rdzobot;
Modules
- alertmanager
- Module
alertmanager: notifications for Prometheus Alertmanager - autojoin
- Module
autojoin: automatically join on invite and leave when owner sends!leave - bot
- The Rdzobot™
- hswaw
- Module
hswaw: assorted tooling for Warsaw Hackerspace - log
- Module
log: logging of individual channels - module
- Writing modules for rdzobot.
- newag
- Module
newag: czy pojazdy jejżdżą? - parcels
- Module
parcels: qrcode generation for receiving parcels from Paczkomat®s - prelude
- Prelude module for rdzobot.
- rcb
- Module
rcb: generating fake RCB alerts - utils
- Misc utils, not fitting anywhere else